@@ -2,6 +2,7 @@
 Implements a client class to query the
 `Deezer API <http://developers.deezer.com/api>`_
 """
+import warnings
 from urllib.parse import urlencode
 
 import requests
@@ -19,6 +20,11 @@ from deezer.resources import (
 )
 from deezer.utils import SortedDict
 
+DEPRECATED_ARG_MESSAGE = (
+    "The `{arg_name}` keyword argument is deprecated "
+    "and will be removed in the next major release."
+)
+
 
 class Client:
     """
@@ -38,10 +44,19 @@ class Client:
 
         >>> import deezer
         >>> client = deezer.Client(headers={'Accept-Language': 'fr'})
-    """
 
-    use_ssl = True
-    host = "api.deezer.com"
+    :param app_id: appliication ID.
+    :param app_secret: application secret.
+    :param access_token: user access token.
+    :param headers: a dictionary of headers to be used.
+
+    .. deprecated:: 1.4.0
+
+    The following parameters will be removed in the next major version:
+
+        * **host** - override the default hostname.
+        * **use_ssl** - connect using HTTP if set to `False`.
+    """
 
     objects_types = {
         "album": Album,
@@ -58,28 +73,37 @@ class Client:
         "chart": Chart,
     }
 
-    def __init__(self, **kwargs):
-        super().__init__()
-
-        self.use_ssl = kwargs.get("use_ssl", self.use_ssl)
-        self.host = kwargs.get("host", self.host)
+    def __init__(
+        self, app_id=None, app_secret=None, access_token=None, headers=None, **kwargs
+    ):
+        self.app_id = app_id
+        self.app_secret = app_secret
+        self.access_token = access_token
+        self.host = "api.deezer.com"
+        self.use_ssl = True
         self.session = requests.Session()
 
-        # Do not compress the response: to be readable in tests (cassettes)
+        # Deprecated arguments
+        deprecated_kwargs = ["host", "use_ssl"]
+        for arg_name in deprecated_kwargs:
+            arg_value = kwargs.get(arg_name)
+            if arg_value is not None:
+                warnings.warn(DEPRECATED_ARG_MESSAGE.format(arg_name=arg_name))
+                setattr(self, arg_name, arg_value)
+
         if kwargs.get("do_not_compress_reponse"):
+            warnings.warn(
+                DEPRECATED_ARG_MESSAGE.format(arg_name="do_not_compress_reponse")
+            )
             self.session.headers.update({"Accept-Encoding": "identity"})
 
         # Headers
-        if kwargs.get("headers"):
-            self.session.headers.update(kwargs.get("headers"))
+        if headers:
+            self.session.headers.update(headers)
 
         self.options = kwargs
         self._authorize_url = None
 
-        self.app_id = kwargs.get("app_id")
-        self.app_secret = kwargs.get("app_secret")
-        self.access_token = kwargs.get("access_token")
-
     def _process_json(self, item, parent=None):
         """
         Recursively convert dictionary
@@ -157,7 +181,9 @@ class Client:
         json = response.json()
         if "error" in json:
             raise ValueError(
-                "API request return error for object: %s id: %s" % (object_t, object_id)
+                "API request return error for object: {} id: {}".format(
+                    object_t, object_id
+                )
             )
         return self._process_json(json, parent)
 
